@@ -7,7 +7,7 @@ use Carp;
 use strict;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-$VERSION = '0.18';
+$VERSION = '0.19';
 
 require Exporter;
 ## require AutoLoader;
@@ -1872,7 +1872,6 @@ sub debug {
     my $self = shift;
     if (ref($self))  {
         if (@_) { $self->{"_DEBUG"} = yes_true ( shift ); }
-        if (wantarray) { return @binary_opt; }
         else {
 	    my $tmp = $self->{"_DEBUG"};
             nocarp || carp "Debug level: $self->{ALIAS} = $tmp";
@@ -1880,13 +1879,10 @@ sub debug {
             return $self->{"_DEBUG"};
         }
     } else {
-        if (@_) { $Verbose = yes_true ( shift ); }
-        if (wantarray) { return @binary_opt; }
-        else {
-            nocarp || carp "Debug Class = $Verbose";
-	    $self->debug_comm($Verbose);
-            return $Verbose;
-        }
+        $Verbose = yes_true ($self);
+        nocarp || carp "SerialPort Debug Class = $Verbose";
+	Win32API::CommPort::debug_comm($Verbose);
+        return $Verbose;
     }
 }
 
@@ -1922,7 +1918,7 @@ Win32::SerialPort - User interface to Win32 Serial API calls
 =head1 SYNOPSIS
 
   require 5.003;
-  use Win32::SerialPort qw( :STAT 0.18 );
+  use Win32::SerialPort qw( :STAT 0.19 );
 
 =head2 Constructors
 
@@ -1978,7 +1974,6 @@ Win32::SerialPort - User interface to Win32 Serial API calls
   $PortObj->parity("odd");
   $PortObj->databits(8);
   $PortObj->stopbits(1);
-  $PortObj->debug(0);
 
      # range parameters return (minimum, maximum) in list context
   $PortObj->xon_limit(100);      # bytes left in buffer
@@ -2002,6 +1997,7 @@ Win32::SerialPort - User interface to Win32 Serial API calls
 
   $PortObj->binary(T);		# just say Yes (Win 3.x option)
   $PortObj->parity_enable(F);	# faults during input
+  $PortObj->debug(0);
 
 =head2 Operating Methods
 
@@ -2968,6 +2964,6 @@ ActiveState 3xx builds. Users of those builds will need to install
 differently (see README). Programs in the test suite are modified for
 the current version. Additions to the configurtion files generated by
 B<save> prevent those created by Version 0.18 from being used by earlier
-Versions. 5 September 1999.
+Versions. 4 November 1999.
 
 =cut
