@@ -65,7 +65,7 @@ $_ResetEvent = new Win32::API("kernel32", "ResetEvent", [N], I);
 use strict;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $RBUF_Size);
-$VERSION = '0.18';
+$VERSION = '0.19';
 $RBUF_Size = 4096;
 
 require Exporter;
@@ -2357,18 +2357,14 @@ sub debug_comm {
     my $self = shift;
     if (ref($self))  {
         if (@_) { $self->{"_DEBUG_C"} = yes_true ( shift ); }
-        if (wantarray) { return @binary_opt; }
         else {
             nocarp or carp "Debug level: $self->{NAME} = $self->{\"_DEBUG_C\"}";
             return $self->{"_DEBUG_C"};
         }
     } else {
-        if (@_) { $Babble = yes_true ( shift ); }
-        if (wantarray) { return @binary_opt; }
-        else {
-            nocarp or carp "Debug Class = $Babble";
-            return $Babble;
-        }
+        $Babble = yes_true ($self);
+        nocarp or carp "CommPort Debug Class = $Babble";
+        return $Babble;
     }
 }
 
@@ -2447,7 +2443,7 @@ Win32API::CommPort - Raw Win32 system API calls for serial communications.
 
   use Win32;	## not required under all circumstances
   require 5.003;
-  use Win32API::CommPort qw( :PARAM :STAT 0.18 );
+  use Win32API::CommPort qw( :PARAM :STAT 0.19 );
 
   ## when available ##  use Win32API::File 0.07 qw( :ALL );
 
@@ -3145,6 +3141,6 @@ ActiveState 3xx builds. Users of those builds will need to install
 differently (see README). Programs in the test suite are modified for
 the current version. Additions to the configurtion files generated by
 B<save> prevent those created by Version 0.15 from being used by earlier
-Versions. 12 August 1999.
+Versions. 4 November 1999.
 
 =cut
